    // The original version of buildDirectories() used a StackOverflow post by user ripper234
    // (http://stackoverflow.com/a/2818246/237176) as partial documentation for XPath.  That user
    // was in turn quoting http://www.roseindia.net/tutorials/xPath/java-xpath.shtml .  The code
    // has been pretty heavily modified since then.
    void buildDirectories(final ProgressBar pb)
      throws ParserConfigurationException, SAXException, IOException, XPathExpressionException, TransformerException {
        if (file != null) {
            DocumentBuilderFactory domFactory = DocumentBuilderFactory.newInstance();
            domFactory.setNamespaceAware(false);
            DocumentBuilder builder = domFactory.newDocumentBuilder();
            doc = builder.parse(file);
            xpath = XPathFactory.newInstance().newXPath();
            buildMetsFile();
            XPathExpression component_expr = getXpathForComponentWithContainers(xpath);

            final NodeList nodes = (NodeList)component_expr.evaluate(doc, XPathConstants.NODESET);
            statusText.setText("Count: " + nodes.getLength());
            Task task = new Task<Void>() {
                @Override protected Void call() throws Exception {
                    final int count = nodes.getLength();
                    for (int i = 0; i < count; i += 1) {
                        final int counter = i + 1;
                        if (isCancelled()) {
                            break;
                        }
                        Node n = nodes.item(i);
                        if (n != null && n.getNodeType() == Node.ELEMENT_NODE) {
                            Queue<String> directory_creation_queue;
                            final XPathExpression containers_expr = xpath.compile("did/container");
                            NodeList containerList = (NodeList)containers_expr.evaluate(n, XPathConstants.NODESET);

                            boolean hasParentAttribute = false;
                            for (int j = 0; j < containerList.getLength(); j += 1) {
                                Node container = containerList.item(j);
                                if (container != null && container.getNodeType() == Node.ELEMENT_NODE) {
                                    NamedNodeMap attributes = container.getAttributes();
                                    if (attributes.getNamedItem("parent") != null) {
                                        hasParentAttribute = true;
                                        break;
                                    }
                                }
                            }

                            class DirectoryQueueBuilder {
                                private Queue<String> directory_queue;
                                private Queue<String> current_directory;
                                private String base;
                                private boolean simple;
                                private boolean finalized = false;

                                private DirectoryQueueBuilder(String base, boolean hasParentAttribute) {
                                    this.base = base;
                                    simple = hasParentAttribute;
                                    directory_queue = new LinkedList<>();
                                    current_directory = new LinkedList<>();
                                }

                                private Queue<String> getDirectoryQueue() {
                                    if (!finalized) {
                                        finalized = true;
                                        processCurrentDirectory();
                                    }
                                    return directory_queue;
                                }

                                private void insert(Node container) {
                                    if (!simple) {
                                        NamedNodeMap attributes = container.getAttributes();
                                        Node parent_id = attributes.getNamedItem("parent");
                                        if (parent_id != null) {
                                            processCurrentDirectory();
                                        }
                                    }
                                    current_directory.add(renderContainer(container));
                                }

                                private void processCurrentDirectory() {
                                    if (current_directory.isEmpty()) {
                                        return;
                                    }
                                    StringBuilder sb = new StringBuilder();
                                    sb.append(directory).append(File.separator);
                                    sb.append(base).append(File.separator);
                                    sb.append(base).append(File.separator);
                                    while (!current_directory.isEmpty()) {
                                        String dir = current_directory.remove();
                                        sb.append(dir);
                                        if (current_directory.peek() != null) {
                                            sb.append(File.separator);
                                        }
                                    }
                                    directory_queue.add(sb.toString());
                                }

                                private String renderContainer(Node container) {
                                    NamedNodeMap attributes = container.getAttributes();
                                    String container_type = "container";
                                    String container_number = container.getTextContent().trim();
                                    String raw_type = normalizeString(attributes.getNamedItem("type").getTextContent());
                                    if (raw_type.length() > 0) {
                                        if (raw_type.equals("othertype")) {
                                            String raw_label = normalizeString(attributes.getNamedItem("label").getTextContent());
                                            if (raw_label.length() > 0) {
                                                container_type = raw_label;
                                            }
                                        } else {
                                            container_type = raw_type;
                                        }
                                    }
                                    // https://gist.github.com/jimjam88/8559505
                                    container_type = Character.toUpperCase(container_type.charAt(0)) + container_type.substring(1);
                                    return container_type + "_" + container_number;
                                }
                            }

                            DirectoryQueueBuilder qb = new DirectoryQueueBuilder(base, hasParentAttribute);

                            for (int j = 0; j < containerList.getLength(); j += 1) {
                                qb.insert(containerList.item(j));
                            }

                            directory_creation_queue = qb.getDirectoryQueue();

                            while (directory_creation_queue.peek() != null) {
                                File subdir = new File(directory_creation_queue.remove());
                                if (!subdir.exists()) {
                                    subdir.mkdirs();
                                }
                            }

                            updateProgress(counter, count);
                            Platform.runLater(() -> {
                                statusText.setText("Processed component " + (counter - 1) + " / " + count);
                            });
                        }
                    }
                    return null;
                }

                @Override protected void succeeded() {
                    super.succeeded();
                    statusText.setText("Finished building folders");
                    pb.setVisible(false);
                }
            };
            pb.progressProperty().unbind();
            pb.progressProperty().bind(task.progressProperty());
            Thread th = new Thread(task);
            th.setDaemon(true);
            th.start();
            pb.setVisible(true);
        }
}