/*
 * This class extends thread to implement a notification mechanism.
 * Based on http://stackoverflow.com/a/702460
 */
abstract class NotifyingThread extends Thread {

    private final Set<ThreadCompleteListener> listeners = new CopyOnWriteArraySet<ThreadCompleteListener>();

    protected final void addListener(final ThreadCompleteListener listener) {
        listeners.add(listener);
    }

    protected final void removeListener(final ThreadCompleteListener listener) {
        listeners.remove(listener);
    }

    protected final void notifyListeners() {
        for (ThreadCompleteListener listener : listeners) {
            listener.notifyOfThreadComplete(this);
        }
    }

    @Override
    public final void run() {
        try {
            doRun();
        } finally {
            notifyListeners();
        }
    }

    protected abstract void doRun();
}