/**
 * Making basic marker a shared instance, this forces only a single popup window to appear on the display
 * based on <a href="http://stackoverflow.com/a/15111870">recommendation</a>
 */
public class MarkerClickInfoWindowSingleton {
    private static MarkerClickInfoWindowSingleton ourInstance = new MarkerClickInfoWindowSingleton();

    public static MarkerClickInfoWindowSingleton getInstance() {
        return ourInstance;
    }
    private final InfoWindow infoWindow;
    private List<MapInfoWindowOpenCloseHandler> listeners = new ArrayList<MapInfoWindowOpenCloseHandler>();

    public MarkerClickInfoWindowSingleton() {
        InfoWindowOptions options = InfoWindowOptions.newInstance();
        options.setMaxWidth(800);
        infoWindow = InfoWindow.newInstance(options);

        infoWindow.addCloseClickHandler(new CloseClickMapHandler() {
            @Override
            public void onEvent(CloseClickMapEvent event) {
                for(MapInfoWindowOpenCloseHandler listener : listeners) {
                    listener.onInfoWindowClose();
                }
            }
        });

    }

    void display(Widget widget, MapWidget mapWidget, MVCObject<?> markerWidget) {
        infoWindow.setContent(widget);
        infoWindow.open(mapWidget, markerWidget);
        for(MapInfoWindowOpenCloseHandler listener : listeners) {
            listener.onInfoWindowOpen();
        }

    }

    public void addInfoWindowOpenCloseHandler(MapInfoWindowOpenCloseHandler listener) {
        listeners.add(listener);
    }

}