/**
 * View pager that sets it's height depending on height of it's biggest child.
 * Based on the StackOverflow <a href="http://stackoverflow.com/a/20784791/1889928">answer by Daniel López Lacalle</a>.
 */
public class WrapContentHeightViewPager extends ViewPager {

    public WrapContentHeightViewPager(final Context context) {
        super(context);
    }

    public WrapContentHeightViewPager(final Context context, final AttributeSet attrs) {
        super(context, attrs);
    }

    @Override
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        int height = 0;

        for(int i = 0; i < getChildCount(); i++) {
            final View child = getChildAt(i);
            child.measure(widthMeasureSpec, MeasureSpec.makeMeasureSpec(0, MeasureSpec.UNSPECIFIED));

            final int measuredHeight = child.getMeasuredHeight();

            if(measuredHeight > height) {
                height = measuredHeight;
            }
        }

        heightMeasureSpec = MeasureSpec.makeMeasureSpec(height, MeasureSpec.EXACTLY);

        super.onMeasure(widthMeasureSpec, heightMeasureSpec);
    }
}