    /**
     * Compute the absolute file path to the JAR file.
     *
     * Found in http://stackoverflow.com/a/20953376
     * The framework is based on http://stackoverflow.com/a/12733172/1614775
     * But that gets it right for only one of the four cases.
     *
     * @param clazz A class residing in the required JAR.
     * @return A File object for the directory in which the JAR file resides.
     * During testing with NetBeans, the result is ./build/classes/,
     * which is the directory containing what will be in the JAR.
     */
    static File getJarDir(Class clazz) {
        return getFileFromUrl(getUrl(clazz), clazz.getName());
    }

    static File getFileFromUrl(URL url, String className) {
        // convert to external form
        String extURL = url.toExternalForm();

        // prune for various cases
        if (extURL.endsWith(".jar")) {
            // from getCodeSource
            extURL = extURL.substring(0, extURL.lastIndexOf('/'));
        } else {
            // from getResource
            String suffix = "/" + className.replace(".", "/") + ".class";
            extURL = extURL.replace(suffix, "");
            if (extURL.startsWith("jar:") && extURL.endsWith(".jar!")) {
                extURL = extURL.substring(FILE_EXTENSION_LENGTH, extURL.lastIndexOf('/'));
            }
        }

        // convert back to URL
        try {
            url = new URL(extURL);
        } catch (MalformedURLException e) {
            // leave url unchanged; probably does not happen
            EmptyStatement.ignore(e);
        }

        // convert URL to File
        try {
            return new File(url.toURI());
        } catch (Exception ignored) {
            return new File(url.getPath());
        }
    }

    private static URL getUrl(Class clazz) {
        try {
            return clazz.getProtectionDomain().getCodeSource().getLocation();
            // URL is in one of two forms
            //        ./build/classes/    NetBeans test
            //        jars/JarName.jar    from a JAR
        } catch (SecurityException e) {
            return clazz.getResource(clazz.getSimpleName() + ".class");
            // URL is in one of two forms, both ending "/com/hazelcast/simulator/wizard/WizardUtils.class"
            //          file:/U:/Simulator/java/simulator/wizard/build/classes
            //          jar:file:/U:/Simulator/java/simulator/wizard/dist/Wizard.jar!
        }
}