    /**
     * Compute the absolute file path to the JAR file.
     * The framework is based on http://stackoverflow.com/a/12733172/1614775, but that gets it right for only one of the
     * four cases.
     *
     * @param aclass A class residing in the required JAR.
     * @return A File object for the directory in which the JAR file resides.
     * <p>
     * During testing with NetBeans, the result is ./build/classes/, which is the directory containing what will be in
     * the JAR. [In this case (IntelliJ + Maven), the result would be ./target/classes/]
     * <p>
     * NOTE: all is based on http://stackoverflow.com/a/20953376/2018219
     */
    public static File getJarDir(Class aclass) {
        URL url;
        String extURL; //  url.toExternalForm();

        // get an url
        try {
            url = aclass.getProtectionDomain().getCodeSource().getLocation();
        } catch (SecurityException ex) {
            url = aclass.getResource(aclass.getSimpleName() + ".class");
        }

        // convert to external form
        extURL = url.toExternalForm();

        // prune for various cases
        if (extURL.endsWith(".jar")) // from getCodeSource
            extURL = extURL.substring(0, extURL.lastIndexOf("/"));
        else {  // from getResource
            String suffix = "/" + (aclass.getName()).replace(".", "/") + ".class";
            extURL = extURL.replace(suffix, "");
            if (extURL.startsWith("jar:") && extURL.endsWith(".jar!"))
                extURL = extURL.substring(4, extURL.lastIndexOf("/"));
        }

        // convert back to url
        try {
            url = new URL(extURL);
        } catch (MalformedURLException mux) {
            // leave url unchanged; probably does not happen
        }

        // convert url to File
        try {
            return new File(url.toURI());
        } catch (URISyntaxException ex) {
            return new File(url.getPath());
        }
}