	static public void DisplayThumbnail(ImageView imageView,
										String path) 
	{
		File file = new File(path);

		if (!file.exists())
		{
			imageView.setImageDrawable(null);  // Clear image
			return;
		}

		// Get the dimensions of the View
		int targetW = imageView.getWidth();
		int targetH = imageView.getHeight();
		if (targetW == 0 || targetH == 0)
		{
			imageView.setImageDrawable(null);  // Clear image
			return;
		}

		// Get the dimensions of the bitmap
		BitmapFactory.Options bmOptions = new BitmapFactory.Options();
		bmOptions.inJustDecodeBounds = true;
		BitmapFactory.decodeFile(path, bmOptions);
		int photoW = bmOptions.outWidth;
		int photoH = bmOptions.outHeight;

		Log.d(LOGGER_TAG, "Current photo path: " + path);
		Log.d(LOGGER_TAG, "Image size: " + photoW + "x" + photoH + ", of " + 
			  new File(path).length() + " bytes");

		// Determine how much to scale down the image
		int scaleFactor = Math.min(photoW/targetW, photoH/targetH);

		// Decode the image file into a Bitmap sized to fill the View
		bmOptions.inJustDecodeBounds = false;
		bmOptions.inSampleSize = scaleFactor;
		bmOptions.inPurgeable = true;

		Bitmap bitmap = BitmapFactory.decodeFile(path, bmOptions);

		// Correct orientation according to EXIF information
		// http://stackoverflow.com/questions/6813166/set-orientation-of-android-camera-started-with-intent-action-image-capture

		try {
			ExifInterface exif = new ExifInterface(path);	
			int orientation = exif.getAttributeInt(ExifInterface.TAG_ORIENTATION, ExifInterface.ORIENTATION_NORMAL);
			int rotate = 0;

			// http://stackoverflow.com/a/12790765/881731
			if (orientation == ExifInterface.ORIENTATION_ROTATE_90) {
				rotate = 90;
			} else if (orientation == ExifInterface.ORIENTATION_ROTATE_180) {
				rotate = 180;
			} else if (orientation == ExifInterface.ORIENTATION_ROTATE_270) {
				rotate = 270;
			}

			Log.d(LOGGER_TAG, "Correcting EXIF orientation: " + rotate);
			
			if (rotate != 0) {
				Matrix matrix = new Matrix();
				matrix.postRotate(rotate);
				bitmap = Bitmap.createBitmap(bitmap, 0, 0, bitmap.getWidth(), bitmap.getHeight(), matrix, true);
			}
		} catch (java.io.IOException e) {
			Log.d(LOGGER_TAG, "Unable to read the EXIF information!");
		}

		imageView.setImageBitmap(bitmap);
}