	private static Drawable createProgressDrawable(ThemeClassDefinition themeClass, Drawable defaultDrawable)
	{
		Integer progressColor = ThemeUtils.getColorId(themeClass.getColor());
		if (progressColor != null && defaultDrawable instanceof LayerDrawable)
		{
			LayerDrawable previous = (LayerDrawable)defaultDrawable;
			Drawable[] themedLayers = new Drawable[previous.getNumberOfLayers()];

			// We only want to change the foreground (progress) layer, leaving everything else as it is.
			for (int i = 0; i < previous.getNumberOfLayers(); i++)
			{
				Drawable previousLayer = previous.getDrawable(i);
				Drawable themedLayer;

				if (previous.getId(i) == android.R.id.progress)
				{
					// Create a gradient by "blackening" the color (60% value).
					float[] progressHsv = new float[3];
					Color.colorToHSV(progressColor, progressHsv);
					progressHsv[2] = (float)(progressHsv[2] * 0.6);
					int progressGradientColor = Color.HSVToColor(Color.alpha(progressColor), progressHsv);

					// Adapted from http://stackoverflow.com/a/12997264/82788
					GradientDrawable color = new GradientDrawable(GradientDrawable.Orientation.TOP_BOTTOM, new int[] { progressColor, progressGradientColor });
					color.setCornerRadius(8);

					themedLayer = new ClipDrawable(color, Gravity.LEFT, ClipDrawable.HORIZONTAL);
				}
				else
					themedLayer = previousLayer;

				themedLayers[i] = themedLayer;
			}

			// Build up the new LayerDrawable.
			LayerDrawable themed = new LayerDrawable(themedLayers);
			for (int i = 0; i < previous.getNumberOfLayers(); i++)
				themed.setId(i, previous.getId(i));

			return themed;
		}
		else
			return defaultDrawable;
}